==> vitriini-2023.3.12.tar.gz: vitriini-2023.3.12/README.md <==
# Vitriini

Showcase (Finnish: vitriini) some packaged content - guided by conventions.

[License: MIT](https://git.sr.ht/~sthagen/vitriini/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![downloads](https://pepy.tech/badge/vitriini/month)](https://pepy.tech/project/vitriini)
[![wheel](https://img.shields.io/pypi/wheel/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![supported-versions](https://img.shields.io/pypi/pyversions/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![supported-implementations](https://img.shields.io/pypi/implementation/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)

## Documentation

User and developer [documentation of vitriini](https://codes.dilettant.life/docs/vitriini).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of vitriini](https://todo.sr.ht/~sthagen/vitriini).

## Primary Source repository

The main source of `vitriini` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `vitriini` are:

* [on codeberg](https://codeberg.org/sthagen/vitriini) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/vitriini) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patch set.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by pointing your browser to [Prepare a patchset](https://git.sr.ht/~sthagen/vitriini/send-email).

# Status

Experimental.

**Note**: The default branch is `default`.

==> vitriini-2023.3.15.tar.gz: vitriini-2023.3.15/README.md <==
# Vitriini

Showcase (Finnish: vitriini) some packaged content - guided by conventions.

[License: MIT](https://git.sr.ht/~sthagen/vitriini/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![downloads](https://pepy.tech/badge/vitriini/month)](https://pepy.tech/project/vitriini)
[![wheel](https://img.shields.io/pypi/wheel/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![supported-versions](https://img.shields.io/pypi/pyversions/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)
[![supported-implementations](https://img.shields.io/pypi/implementation/vitriini.svg?style=flat)](https://pypi.python.org/pypi/vitriini/)

## Documentation

User and developer [documentation of vitriini](https://codes.dilettant.life/docs/vitriini).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of vitriini](https://todo.sr.ht/~sthagen/vitriini).

## Primary Source repository

The main source of `vitriini` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `vitriini` are:

* [on codeberg](https://codeberg.org/sthagen/vitriini) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/vitriini) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note**: The default branch is `default`.
